@@ -8,8 +8,8 @@ htmlTreeParse <-
 #       the XML text, and parse that.
 # See also xml
 #
-function(file="../XML/Docs/test.xml", ignoreBlanks = T, handlers=NULL,
-           replaceEntities=F, asText=F, trim=T, isURL=F, asTree = F)
+function(file="../XML/Docs/test.xml", ignoreBlanks = TRUE, handlers=NULL,
+           replaceEntities=FALSE, asText=FALSE, trim=TRUE, isURL=FALSE, asTree = FALSE)
 {
   if(missing(isURL)) {
     isURL <- length(grep("http://",file)) | length(grep("ftp://",file))
@@ -18,8 +18,8 @@ function(file="../XML/Docs/test.xml", ignoreBlanks = T, handlers=NULL,
     # check whether we are treating the file name as
     # a) the XML text itself, or b) as a URL.
     # Otherwise, check if the file exists and report an error.
- if(asText == F & isURL == F) {
-  if(file.exists(file) == F)
+ if(asText == FALSE & isURL == FALSE) {
+  if(file.exists(file) == FALSE)
      stop(paste("File", file, "does not exist "))
  }
 
